@@ -18,10 +18,11 @@ package com.jetbrains.python.psi;
 import com.intellij.lang.annotation.HighlightSeverity;
 import com.intellij.psi.PsiReference;
 import com.jetbrains.python.psi.types.TypeEvalContext;
+import org.jetbrains.annotations.Nls;
 import org.jetbrains.annotations.Nullable;
 
 public interface PsiReferenceEx extends PsiReference {
   @Nullable
   HighlightSeverity getUnresolvedHighlightSeverity(TypeEvalContext context);
-  @Nullable String getUnresolvedDescription();
+  @Nullable @Nls String getUnresolvedDescription();
 }
