@@ -16,6 +16,7 @@ from _pydev_bundle.pydev_console_types import CodeFragment, Command
 from _pydev_bundle.pydev_imports import Exec
 from _pydevd_bundle import pydevd_vars, pydevd_save_locals
 from _pydevd_bundle.pydevd_console_pytest import enable_pytest_output
+from _pydevd_bundle.pydevd_asyncio_provider import get_asyncio_command_compiler, get_exec_async_code, get_apply
 
 try:
     import __builtin__
@@ -175,7 +176,6 @@ def console_exec(thread_id, frame_id, expression, dbg):
     """
     frame = pydevd_vars.find_frame(thread_id, frame_id)
 
-    is_multiline = expression.count('@LINE@') > 1
     try:
         expression = str(expression.replace('@LINE@', '\n'))
     except UnicodeEncodeError as e:
@@ -192,6 +192,9 @@ def console_exec(thread_id, frame_id, expression, dbg):
         enable_pytest_output()
 
     if IPYTHON:
+        apply_func = get_apply()
+        if apply_func is not None:
+            apply_func()
         need_more, exception_occurred = ipython_exec_code(CodeFragment(expression), updated_globals, updated_globals, dbg)
         if not need_more:
             update_frame_local_variables_and_save(frame, updated_globals)
@@ -199,29 +202,38 @@ def console_exec(thread_id, frame_id, expression, dbg):
 
     interpreter = ConsoleWriter()
 
-    if not is_multiline:
+    try:
+        async_compiler = get_asyncio_command_compiler()
+        if async_compiler is not None:
+            compiler = async_compiler
+        else:
+            compiler = compile_command
         try:
-            code = compile_command(expression)
+            code = compiler(expression)
         except (OverflowError, SyntaxError, ValueError):
-            # Case 1
-            interpreter.showsyntaxerror()
-            return False, True
-        if code is None:
-            # Case 2
-            return True, False
-    else:
-        code = expression
+            code = compiler(expression, symbol='exec')
+    except (OverflowError, SyntaxError, ValueError):
+        # Case 1
+        interpreter.showsyntaxerror()
+        return False, True
+    if code is None:
+        # Case 2
+        return True, False
 
     # Case 3
     code_executor = get_code_executor()
     code_executor.interruptable = True
     exception_occurred = False
     try:
-        # It is important that globals and locals we pass to the exec function are the same object.
-        # Otherwise generator expressions can confuse their scope. Passing updated_globals dictionary seems to be a safe option here
-        # because it contains globals and locals in the right precedence.
-        # See: https://stackoverflow.com/questions/15866398/why-is-a-python-generator-confusing-its-scope-with-global-in-an-execd-script.
-        Exec(code, updated_globals, updated_globals)
+        exec_func = get_exec_async_code()
+        if exec_func is not None:
+            exec_func(code, updated_globals)
+        else:
+            # It is important that globals and locals we pass to the exec function are the same object.
+            # Otherwise generator expressions can confuse their scope. Passing updated_globals dictionary seems to be a safe option here
+            # because it contains globals and locals in the right precedence.
+            # See: https://stackoverflow.com/questions/15866398/why-is-a-python-generator-confusing-its-scope-with-global-in-an-execd-script.
+            Exec(code, updated_globals, updated_globals)
     except:
         interpreter.showtraceback()
         exception_occurred = True
